@@ -6,7 +6,7 @@ from starlette.requests import cookie_parser
 from starlite.datastructures import State
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.parsers import parse_query_params
-from starlite.types import Empty
+from starlite.types import Empty, Logger
 
 if TYPE_CHECKING:
     from typing import MutableMapping
@@ -214,6 +214,18 @@ class ASGIConnection(Generic[Handler, User, Auth]):
             )
         return cast("Dict[str, Any]", self.scope["session"])
 
+    @property
+    def logger(self) -> Logger:
+        """
+
+        Returns:
+            A 'Logger' instance.
+
+        Raises:
+            ImproperlyConfiguredException: if 'log_config' has not been passed to the Starlite constructor.
+        """
+        return self.app.get_logger()
+
     def set_session(self, value: Union[Dict[str, Any], "BaseModel"]) -> None:
         """Helper method to set the session in scope.
 
