@@ -9,9 +9,7 @@ from starlite.types import Dependencies, ExceptionHandler, Guard, Middleware
 from starlite.utils import is_async_callable
 
 if TYPE_CHECKING:
-    from pydantic.typing import AnyCallable
-
-    from starlite.types import AsyncAnyCallable
+    from starlite.types import AnyCallable, AsyncAnyCallable
 
 
 class WebsocketRouteHandler(BaseRouteHandler["WebsocketRouteHandler"]):
@@ -26,7 +24,7 @@ class WebsocketRouteHandler(BaseRouteHandler["WebsocketRouteHandler"]):
         middleware: Optional[List[Middleware]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
-    ):
+    ) -> None:
         """WebSocket Route Handler decorator. Use this decorator to decorate
         websocket handler functions.
 
