@@ -14,8 +14,8 @@ if TYPE_CHECKING:
     from typing import Union
 
     from pydantic.fields import ModelField
-    from starlette.requests import HTTPConnection
 
+    from starlite.connection import ASGIConnection
     from starlite.datastructures import FormMultiDict
 
 _true_values = {"True", "true"}
@@ -42,7 +42,7 @@ def _query_param_reducer(acc: Dict[str, List[Any]], cur: Tuple[str, str]) -> Dic
     return acc
 
 
-def parse_query_params(connection: "HTTPConnection") -> Dict[str, Any]:
+def parse_query_params(connection: "ASGIConnection") -> Dict[str, Any]:
     """Parses and normalize a given connection's query parameters into a
     regular dictionary."""
     query_string = cast("Union[str, bytes]", connection.scope.get("query_string", ""))
@@ -67,11 +67,11 @@ def parse_form_data(media_type: "RequestEncodingType", form_data: "FormMultiDict
         if not isinstance(value, MultipartUploadFile):
             with suppress(JSONDecodeError):
                 value = loads(value)
-        if values_dict.get(key):
-            if isinstance(values_dict[key], list):
-                values_dict[key].append(value)
-            else:
-                values_dict[key] = [values_dict[key], value]
+        existing_value = values_dict.get(key)
+        if isinstance(existing_value, list):
+            values_dict[key].append(value)
+        elif existing_value:
+            values_dict[key] = [existing_value, value]
         else:
             values_dict[key] = value
     if media_type == RequestEncodingType.MULTI_PART:
