@@ -6,9 +6,8 @@ from starlite.utils import AsyncCallable, is_async_callable
 if TYPE_CHECKING:
     from typing import Type
 
-    from pydantic.typing import AnyCallable
-
     from starlite.signature import SignatureModel
+    from starlite.types import AnyCallable
 
 
 class Provide:
@@ -22,7 +21,7 @@ class Provide:
 
     __slots__ = ("dependency", "use_cache", "value", "signature_model")
 
-    def __init__(self, dependency: "AnyCallable", use_cache: bool = False, sync_to_thread: bool = False):
+    def __init__(self, dependency: "AnyCallable", use_cache: bool = False, sync_to_thread: bool = False) -> None:
 
         self.dependency = cast("AnyCallable", AsyncCallable(dependency) if sync_to_thread else dependency)
         self.use_cache = use_cache
